@@ -1,6 +1,6 @@
 use crate::resource::{NavMeshID, NavPathMode, NavQuery, NavVec3};
 use core::{
-    ecs::{Component, Entity, NullStorage, VecStorage},
+    ecs::Entity,
     id::ID,
     prefab::{Prefab, PrefabComponent},
     Ignite, Scalar,
@@ -14,10 +14,6 @@ pub type NavAgentId = ID<NavAgent>;
 #[derive(Ignite, Debug, Default, Copy, Clone, Serialize, Deserialize)]
 pub struct SimpleNavDriverTag;
 
-impl Component for SimpleNavDriverTag {
-    type Storage = NullStorage<Self>;
-}
-
 impl Prefab for SimpleNavDriverTag {}
 impl PrefabComponent for SimpleNavDriverTag {}
 
@@ -79,10 +75,6 @@ pub struct NavAgent {
     pub(crate) dirty_path: bool,
 }
 
-impl Component for NavAgent {
-    type Storage = VecStorage<Self>;
-}
-
 impl Default for NavAgent {
     fn default() -> Self {
         Self::new(Default::default())
